<?php
require_once 'config.php';
require_once 'vendor/autoload.php';

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, X-Xtool-Token, Content-Type");
header("Content-Type: application/json");

// 🔍 Token'ı al (önce özel header, sonra Authorization)
$token = null;

// 1. X-Xtool-Token üzerinden gelen token varsa onu al
if (isset($_SERVER['HTTP_X_XTOOL_TOKEN'])) {
    $token = trim($_SERVER['HTTP_X_XTOOL_TOKEN']);
}

// 2. Authorization varsa oradan al (backup)
elseif (isset($_SERVER['HTTP_AUTHORIZATION'])) {
    if (preg_match('/Bearer\s(\S+)/', $_SERVER['HTTP_AUTHORIZATION'], $matches)) {
        $token = $matches[1];
    }
}

// 3. REDIRECT_HTTP_AUTHORIZATION (bazı apache yapılandırmaları için)
elseif (isset($_SERVER['REDIRECT_HTTP_AUTHORIZATION'])) {
    if (preg_match('/Bearer\s(\S+)/', $_SERVER['REDIRECT_HTTP_AUTHORIZATION'], $matches)) {
        $token = $matches[1];
    }
}

if (!$token) {
    http_response_code(401);
    echo json_encode(['success' => false, 'error' => 'Token alınamadı (X-Xtool-Token veya Authorization yok).']);
    exit;
}

try {
    $decoded_token = JWT::decode($token, new Key(JWT_SECRET_KEY, JWT_ALGO));
    $GLOBALS['decoded_token'] = $decoded_token;
} catch (Exception $e) {
    http_response_code(401);
    echo json_encode(['success' => false, 'error' => 'Token geçersiz: ' . $e->getMessage()]);
    exit;
}
