<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

require_once("config.php");
require_once("database.php");
require_once("auth-check.php");

// Sadece admin izinli
if ($decoded_token->data->role !== 'admin') {
    http_response_code(403);
    echo json_encode(['success' => false, 'error' => 'Yetkisiz erişim']);
    exit;
}

// JSON'dan gelen veriyi al
$data = json_decode(file_get_contents("php://input"), true);
$licenseId = $data["id"] ?? null;
$daysToAdd = $data["days"] ?? 30;

if (!$licenseId || !is_numeric($daysToAdd)) {
    echo json_encode(["success" => false, "error" => "Geçersiz veri"]);
    exit;
}

// Mevcut bitiş tarihini al
$stmt = $conn->prepare("SELECT end_date FROM user_licenses WHERE id = ?");
$stmt->bind_param("i", $licenseId);
$stmt->execute();
$result = $stmt->get_result();
$current = $result->fetch_assoc();
$stmt->close();

if (!$current) {
    echo json_encode(["success" => false, "error" => "Lisans bulunamadı"]);
    exit;
}

$currentEnd = new DateTime($current["end_date"]);
$currentEnd->modify("+{$daysToAdd} days");
$newEndDate = $currentEnd->format("Y-m-d");

// Güncelle
$update = $conn->prepare("UPDATE user_licenses SET end_date = ? WHERE id = ?");
$update->bind_param("si", $newEndDate, $licenseId);
$success = $update->execute();
$update->close();

echo json_encode([
  "success" => $success,
  "new_end_date" => $newEndDate
]);
