<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

require_once("config.php");
require_once("database.php");
require_once("auth-check.php");

// Sadece admin erişebilir
if ($decoded_token->data->role !== 'admin') {
    http_response_code(403);
    echo json_encode(['success' => false, 'error' => 'Bu işlem için yetkiniz yok.']);
    exit;
}

// Kullanıcı ID kontrolü
$data = json_decode(file_get_contents("php://input"), true);
$userId = $data["user_id"] ?? null;

if (!$userId) {
    echo json_encode(["success" => false, "error" => "Kullanıcı ID eksik."]);
    exit;
}

// Kullanıcı bilgisi
$stmtUser = $conn->prepare("SELECT name, email FROM users WHERE id = ?");
$stmtUser->bind_param("i", $userId);
$stmtUser->execute();
$userResult = $stmtUser->get_result();
$user = $userResult->fetch_assoc();
$stmtUser->close();

if (!$user) {
    echo json_encode(["success" => false, "error" => "Kullanıcı bulunamadı."]);
    exit;
}

// Lisans bilgileri
$stmt = $conn->prepare("
  SELECT ul.id, ul.start_date, ul.end_date, ul.note, p.name AS package_name
  FROM user_licenses ul
  JOIN packages p ON ul.package_id = p.id
  WHERE ul.user_id = ?
  ORDER BY ul.end_date DESC
");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

$licenses = [];
while ($row = $result->fetch_assoc()) {
    $licenses[] = $row;
}

echo json_encode([
    "success" => true,
    "user" => $user,
    "licenses" => $licenses
]);
