<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

date_default_timezone_set('Europe/Istanbul');

// ✅ CORS HEADERS
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    header("Access-Control-Allow-Origin: *");
    header("Access-Control-Allow-Headers: Authorization, Content-Type");
    header("Access-Control-Allow-Methods: POST, OPTIONS");
    http_response_code(200);
    exit;
}

header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

require __DIR__ . '/vendor/autoload.php';
require_once("config.php");
require_once("database.php");

$data = json_decode(file_get_contents("php://input"), true);
$email = trim($data['email'] ?? '');

if (!$email || !filter_var($email, FILTER_VALIDATE_EMAIL)) {
    echo json_encode(["success" => false, "error" => "Geçerli bir e-posta giriniz."]);
    exit;
}

// ✅ Kullanıcıyı kontrol et
$stmt = $conn->prepare("SELECT id, name FROM users WHERE email = ?");
$stmt->bind_param("s", $email);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();
$stmt->close();

if (!$user) {
    echo json_encode(["success" => false, "error" => "Bu e-posta sistemde kayıtlı değil."]);
    exit;
}

// ✅ Süresi dolmamış kod varsa tekrar gönderme
$stmt = $conn->prepare("SELECT * FROM password_resets WHERE user_id = ? AND expires_at >= NOW()");
$stmt->bind_param("i", $user['id']);
$stmt->execute();
$active = $stmt->get_result()->fetch_assoc();
$stmt->close();

if ($active) {
    echo json_encode(["success" => false, "error" => "Zaten bir doğrulama kodu gönderildi. Lütfen birkaç dakika sonra tekrar deneyin."]);
    exit;
}

// ✅ Önceki geçmiş kayıtları temizle
$conn->query("DELETE FROM password_resets WHERE user_id = {$user['id']}");

// ✅ Yeni kod oluştur
$code = rand(100000, 999999);
$expires = date("Y-m-d H:i:s", strtotime("+10 minutes"));

// ✅ Yeni kodu kaydet
$stmt = $conn->prepare("INSERT INTO password_resets (user_id, code, expires_at) VALUES (?, ?, ?)");
$stmt->bind_param("iss", $user['id'], $code, $expires);
$stmt->execute();
$stmt->close();

// ✅ Mail gönder
$mail = new PHPMailer(true);
try {
    $mail->isSMTP();
    $mail->Host = 'mail.bulutgroup.org';
    $mail->SMTPAuth = true;
    $mail->Username = 'info@bulutgroup.org';
    $mail->Password = '4cNtjpGCbtWwjcf';
    $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
    $mail->Port = 465;

    $mail->SMTPOptions = [
        'ssl' => [
            'verify_peer' => false,
            'verify_peer_name' => false,
            'allow_self_signed' => true,
        ],
    ];

    $mail->setFrom('info@bulutgroup.org', 'XTool Destek');
    $mail->addAddress($email, $user['name']);
    $mail->isHTML(true);
    $mail->CharSet = "UTF-8";
    $mail->Encoding = "base64";
    $mail->Subject = '🔐 Şifre Sıfırlama Kodu';
    $mail->Body = "
        Merhaba <strong>{$user['name']}</strong>,<br><br>
        Şifrenizi sıfırlamak için gereken doğrulama kodu aşağıdadır:<br><br>
        <h2 style='color:#4f46e5;'>$code</h2>
        <p>Kod 10 dakika boyunca geçerlidir. Eğer bu işlemi siz başlatmadıysanız dikkate almayınız.</p>
        <br>
        — XTool Destek Ekibi
    ";

    $mail->send();
    echo json_encode(["success" => true]);
} catch (Exception $e) {
    echo json_encode(["success" => false, "error" => "Mail gönderilemedi: " . $mail->ErrorInfo]);
}
