<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Content-Type, Authorization");
header("Content-Type: application/json");

require_once("config.php");
require_once("database.php");
require __DIR__ . '/vendor/autoload.php';

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

$raw = file_get_contents("php://input");
$data = json_decode($raw, true);
$headers = getallheaders();
$token = $headers['Authorization'] ?? ($_SERVER['HTTP_AUTHORIZATION'] ?? '');

if (!$token) {
    echo json_encode(["success" => false, "error" => "Token gerekli."]);
    exit;
}

try {
    $decoded = JWT::decode($token, new Key(JWT_SECRET_KEY, JWT_ALGO));
    $userId = $decoded->sub;

    $name  = trim($data["name"] ?? '');
    $email = trim($data["email"] ?? '');
    $phone = trim($data["phone"] ?? '');

    if (!$name || !$email || !$phone) {
        echo json_encode(["success" => false, "error" => "Lütfen tüm alanları doldurun."]);
        exit;
    }

    // Kullanıcının mevcut bilgilerini getir
    $check = $conn->prepare("SELECT username, created_at, balance, country_city, last_profile_update FROM users WHERE id = ?");
    $check->bind_param("i", $userId);
    $check->execute();
    $result = $check->get_result();
    $user = $result->fetch_assoc();
    $check->close();

    // 7 gün kontrolü
    if ($user && $user['last_profile_update']) {
        $lastUpdate = new DateTime($user['last_profile_update']);
        $now = new DateTime();
        $diff = $now->diff($lastUpdate)->days;

        if ($diff < 7) {
            $remaining = 7 - $diff;
            echo json_encode([
                "success" => false,
                "error" => "Hesap bilgilerini 7 günde bir güncelleyebilirsiniz. Kalan süre: {$remaining} gün"
            ]);
            exit;
        }
    }

    // Kullanıcı bilgilerini güncelle
    $stmt = $conn->prepare("UPDATE users SET name = ?, email = ?, phone = ?, last_profile_update = NOW() WHERE id = ?");
    $stmt->bind_param("sssi", $name, $email, $phone, $userId);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        $updatedTime = date("Y-m-d H:i:s");

        // Yeni token oluştur
        $payload = [
            "iss" => "xtool",
            "aud" => "xtool-users",
            "iat" => time(),
            "exp" => time() + JWT_EXPIRE_TIME,
            "sub" => $userId,
            "data" => [
                "id" => $userId,
                "name" => $name,
                "username" => $user["username"],
                "email" => $email,
                "phone" => $phone,
                "balance" => $user["balance"],
                "country_city" => $user["country_city"],
                "created_at" => $user["created_at"],
                "last_profile_update" => $updatedTime
            ]
        ];

        $newToken = JWT::encode($payload, JWT_SECRET_KEY, JWT_ALGO);

        echo json_encode([
            "success" => true,
            "message" => "Profil başarıyla güncellendi.",
            "token" => $newToken
        ]);
    } else {
        echo json_encode([
            "success" => false,
            "error" => "Güncelleme yapılamadı. Aynı bilgileri giriyor olabilirsiniz."
        ]);
    }

    $stmt->close();
    $conn->close();

} catch (Exception $e) {
    echo json_encode(["success" => false, "error" => "Token doğrulanamadı."]);
}
