<?php
require_once("config.php");
require_once("database.php");

header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

date_default_timezone_set('Europe/Istanbul');

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

$data = json_decode(file_get_contents("php://input"), true);
$email = trim($data['email'] ?? '');
$code = trim($data['code'] ?? '');

if (!$email || !$code) {
    echo json_encode(["success" => false, "error" => "E-posta ve kod gereklidir."]);
    exit;
}

// Kullanıcı ID’sini al
$stmt = $conn->prepare("SELECT id FROM users WHERE email = ?");
$stmt->bind_param("s", $email);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();
$stmt->close();

if (!$user) {
    echo json_encode(["success" => false, "error" => "Kullanıcı bulunamadı."]);
    exit;
}

// Kod geçerli mi kontrol et
$stmt = $conn->prepare("
  SELECT * FROM password_resets
  WHERE user_id = ? AND code = ? AND expires_at >= NOW()
");
$stmt->bind_param("is", $user['id'], $code);
$stmt->execute();
$result = $stmt->get_result();
$valid = $result->fetch_assoc();
$stmt->close();

if (!$valid) {
    echo json_encode(["success" => false, "error" => "Kod geçersiz veya süresi dolmuş."]);
    exit;
}

echo json_encode(["success" => true]);
